@@ -39,19 +39,21 @@ sub generate_conf {
         try_win32_native ($check, \$longest, $defines);
 
         try_headers($check, \$longest, $defines, qw(
-            -HAVE_WINDOWS_H       Windows.h
+            HAVE_WINDOWS_H       Windows.h
             HAVE_WINSOCK2_H      winsock2.h
             HAVE_IPHLPAPI_H      iphlpapi.h
+            HAVE_BCRYPT_H        bcrypt.h
             HAVE_CTYPE_H         ctype.h
             HAVE_ERR_H           err.h
             HAVE_ERRNO_H         errno.h
-            -HAVE_FCNTL_H         fcntl.h
+            HAVE_FCNTL_H         fcntl.h
             HAVE_INTTYPES_H      inttypes.h
             HAVE_IO_H            io.h
             HAVE_NETINET_IN_H    netinet/in.h
             HAVE_NET_IF_DL_H     net/if_dl.h
             HAVE_NET_IF_H        net/if.h
             HAVE_PROCESS_H       process.h
+            HAVE_PTHREAD_H       pthread.h
             HAVE_STDINT_H        stdint.h
             HAVE_STDIO_H         stdio.h
             HAVE_STDLIB_H        stdlib.h
@@ -68,15 +70,18 @@ sub generate_conf {
             HAVE_SYS_WAIT_H      sys/wait.h
             HAVE_TIME_H          time.h
             HAVE_UNISTD_H        unistd.h
+            HAVE_WINCRYPT_H      wincrypt.h
         ));
 
-        try_arc4random   ($check, \$longest, $defines);
-        try_getentropy   ($check, \$longest, $defines);
-        try_getrandom    ($check, \$longest, $defines);
-        try_lstat        ($check, \$longest, $defines);
-        try_sa_len       ($check, \$longest, $defines);
-        try_symlink      ($check, \$longest, $defines);
-        #try_threads      ($check, \$longest, $defines);
+        try_arc4random      ($check, \$longest, $defines);
+        try_BCryptGenRandom ($check, \$longest, $defines);
+        try_CryptGenRandom  ($check, \$longest, $defines);
+        try_getentropy      ($check, \$longest, $defines);
+        try_getrandom       ($check, \$longest, $defines);
+        try_lstat           ($check, \$longest, $defines);
+        try_sa_len          ($check, \$longest, $defines);
+        try_symlink         ($check, \$longest, $defines);
+        #try_threads         ($check, \$longest, $defines);
     }
 }
 
@@ -174,6 +179,66 @@ sub try_arc4random {
     unlink $conf;
 }
 
+sub try_BCryptGenRandom {
+    my ($check, $long, $defs) = @_;
+    my $msg = 'Checking BCryptGenRandom()';
+    my $len = length $msg;
+    if ($check) { $$long = $len if $len > $$long; return; }
+    my $more = $$long - $len;
+    my $conf = gen_confh($defs);
+    if ( check_lib(
+        header   => $conf,
+        lib      => 'bcrypt',
+        ccflags  => '-I.',
+        debug    => 0,
+        function => q{
+            unsigned char p[4];
+            int r, c = 4;
+            r = BCryptGenRandom(NULL, p, c, BCRYPT_USE_SYSTEM_PREFERRED_RNG);
+            return 0;
+            (void)r;
+        },
+    )) {
+        push @$defs, '#define HAVE_BCRYPTGENRANDOM 1';
+        print $msg, ' ..', '.'x$more, ' found';
+    }
+    else {
+        push @$defs, '#undef HAVE_BCRYPTGENRANDOM';
+        print $msg, ' ..', '.'x$more, ' missing';
+    }
+    unlink $conf;
+}
+
+sub try_CryptGenRandom {
+    my ($check, $long, $defs) = @_;
+    my $msg = 'Checking CryptGenRandom()';
+    my $len = length $msg;
+    if ($check) { $$long = $len if $len > $$long; return; }
+    my $more = $$long - $len;
+    my $conf = gen_confh($defs);
+    if ( check_lib(
+        header   => $conf,
+        lib      => 'crypto',
+        ccflags  => '-I.',
+        debug    => 0,
+        function => q{
+            unsigned char p[4];
+            int r, c = 4;
+            r = CryptGenRandom((HCRYPTPROV)NULL, c, p);
+            return 0;
+            (void)r;
+        },
+    )) {
+        push @$defs, '#define HAVE_CRYPTGENRANDOM 1';
+        print $msg, ' ..', '.'x$more, ' found';
+    }
+    else {
+        push @$defs, '#undef HAVE_CRYPTGENRANDOM';
+        print $msg, ' ..', '.'x$more, ' missing';
+    }
+    unlink $conf;
+}
+
 sub try_getentropy {
     my ($check, $long, $defs) = @_;
     my $msg = 'Checking getentropy()';
