@@ -147,25 +147,28 @@ typedef struct {
 typedef U8 uu_t[16];
 
 typedef struct {
-  U64               xo_s[4];
-  U64               sm_x;
-  U64               gen_epoch;
-  U8                gen_node[6];  /* need 64bit align */
-  U16               __align;
-  U8                gen_real_node[6];  /* need 64bit align */
-  void              (*myU2time)(pTHX_ UV ret[2]);
-  int               gen_has_real_node;
-  int               gen_use_unique;
-  cc_st             cc;  /* aligned 64bit */
-  int               clock_state_fd;
-  FILE              *clock_state_f;
-  struct_pathlen_t  clock_pathlen;
-  int               clock_adj;
-  struct timeval    clock_last;
-  U16               clock_seq;
-  UV                thread_id;
-  U64               clock_defer_100ns;
-  U64               clock_prev_reg;
+  U64               thread_id;          /*    8 bytes */
+  U64               gen_epoch;          /*    8 bytes */
+  U8                gen_node[6];        /*    6 bytes */  /* need 64bit align */
+  U16               gen_has_real_node;  /*    2 bytes */
+  U8                gen_real_node[6];   /*    6 bytes */  /* need 64bit align */
+  U16               gen_use_unique;     /*    2 bytes */
+  U8                __pad0[32];         /*   32 bytes */
+  /* -- 64 bytes -- */
+  cc_st             cc;                 /* 1104 bytes */  /* aligned 64bit */
+  U64               xo_s[4];            /*   32 bytes */
+  U64               sm_x;               /*    8 bytes */
+  U8                __pad1[8];          /*    8 bytes */
+  /* -- 64 bytes * 18  -- */
+  struct_pathlen_t  clock_pathlen;      /*   16 bytes */
+  struct timeval    clock_last;         /*   16 bytes */
+  FILE              *clock_state_f;     /*    8 bytes */
+  U64               clock_prev_reg;     /*    8 bytes */
+  U64               clock_defer_100ns;  /*    8 bytes */
+  I32               clock_state_fd;     /*    4 bytes */
+  I16               clock_adj;          /*    2 bytes */
+  U16               clock_seq;          /*    2 bytes */
+  /* -- 64 bytes -- */
 } my_cxt_t;
 
 /* no *UCXT_ variants, just use a comma */
